.. _examples-index:

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Seatray has a builtint HDF5 writer. This is how to read the file. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_h5_ant_thumb.png

        :ref:`sphx_glr_auto_examples_h5_ant.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/h5_ant

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Create a simple histogram of the PMT signals (ToTs) in all events. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_tot_histogram_thumb.png

        :ref:`sphx_glr_auto_examples_plot_tot_histogram.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_tot_histogram

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Choosing the right colormap is important. A bad colormap like ``jet`` (standard in ROOT and mat...">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_colourmap_pitfalls_thumb.png

        :ref:`sphx_glr_auto_examples_plot_colourmap_pitfalls.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_colourmap_pitfalls

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to create a zt-plot of a given DU and event ID. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_zt_thumb.png

        :ref:`sphx_glr_auto_examples_plot_zt.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_zt

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example needs Astropy: `pip install astropy`.">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_astro_orca_thumb.png

        :ref:`sphx_glr_auto_examples_plot_astro_orca.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_astro_orca

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Estimate track/DOM distances using the number of hits per DOM. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_dom_hits_thumb.png

        :ref:`sphx_glr_auto_examples_plot_dom_hits.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_dom_hits

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Histograms, PDF fits, Kernel Density. ">

.. only:: html

    .. figure:: /auto_examples/images/thumb/sphx_glr_plot_fitting_dists_thumb.png

        :ref:`sphx_glr_auto_examples_plot_fitting_dists.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_fitting_dists
.. raw:: html

    <div style='clear:both'></div>



.. container:: sphx-glr-footer


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip </auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </auto_examples/auto_examples_jupyter.zip>`

.. rst-class:: sphx-glr-signature

    `Generated by Sphinx-Gallery <http://sphinx-gallery.readthedocs.io>`_
